@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,8 +15,8 @@
 
   MagickCore string methods.
 */
-#ifndef _MAGICKCORE_STRING_H_
-#define _MAGICKCORE_STRING_H_
+#ifndef MAGICKCORE_STRING_H_
+#define MAGICKCORE_STRING_H_
 
 #include <stdarg.h>
 #include <time.h>
@@ -48,6 +48,7 @@ extern MagickExport char
   *EscapeString(const char *,const char),
   *FileToString(const char *,const size_t,ExceptionInfo *),
   *GetEnvironmentValue(const char *),
+  *SanitizeString(const char *),
   *StringInfoToHexString(const StringInfo *),
   *StringInfoToString(const StringInfo *),
   **StringToArgv(const char *,int *),
