@@ -27,12 +27,12 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "© 1999-2017 ImageMagick Studio LLC"
-#define MagickLibVersion  0x698
-#define MagickLibVersionText  "6.9.8"
-#define MagickLibVersionNumber  4,0,0
-#define MagickLibAddendum  "-3"
-#define MagickLibInterface  4
-#define MagickLibMinInterface  4
+#define MagickLibVersion  0x699
+#define MagickLibVersionText  "6.9.9"
+#define MagickLibVersionNumber  5,0,0
+#define MagickLibAddendum  "-11"
+#define MagickLibInterface  5
+#define MagickLibMinInterface  5
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -40,14 +40,14 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "mips64"
+#define MagickPlatform  "alpha"
 #endif
-#define MagickppLibVersionText  "6.9.8"
-#define MagickppLibVersionNumber  7:0:0
-#define MagickppLibAddendum  "-3"
-#define MagickppLibInterface  7
-#define MagickppLibMinInterface  7
-#define MagickReleaseDate  "2017-04-07"
+#define MagickppLibVersionText  "6.9.9"
+#define MagickppLibVersionNumber  8:0:0
+#define MagickppLibAddendum  "-11"
+#define MagickppLibInterface  8
+#define MagickppLibMinInterface  8
+#define MagickReleaseDate  "2017-10-05"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "http://www.imagemagick.org/script/license.php"
